==> totem-3.15.4.tar.xz: totem-3.15.4/src/icon-helpers.h <==
/*
 * Copyright (C) 2013 Bastien Nocera <hadess@hadess.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 * The Totem project hereby grant permission for non-gpl compatible GStreamer
 * plugins to be used and distributed together with GStreamer and Totem. This
 * permission are above and beyond the permissions granted by the GPL license
 * Totem is covered by.
 *
 * Monday 7th February 2005: Christian Schaller: Add exception clause.
 * See license_change file for details.
 *
 */

#include <totem.h>
#include <grilo.h>

void             totem_grilo_setup_icons          (Totem *self);
void             totem_grilo_clear_icons          (void);
GdkPixbuf       *totem_grilo_get_icon             (GrlMedia *media,
						   gboolean *thumbnailing);
const GdkPixbuf *totem_grilo_get_video_icon       (void);
const GdkPixbuf *totem_grilo_get_box_icon         (void);
const GdkPixbuf *totem_grilo_get_optical_icon     (void);

void             totem_grilo_pause_icon_thumbnailing  (void);
void             totem_grilo_resume_icon_thumbnailing (void);

void             totem_grilo_get_thumbnail        (GObject             *object,
						   GCancellable        *cancellable,
						   GAsyncReadyCallback  callback,
						   gpointer             user_data);
GdkPixbuf       *totem_grilo_get_thumbnail_finish (GObject             *object,
						   GAsyncResult        *res,
						   GError             **error);

==> totem_3.34.1.orig.tar.xz: totem-3.34.1/src/icon-helpers.h <==
/*
 * Copyright (C) 2013 Bastien Nocera <hadess@hadess.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 * The Totem project hereby grant permission for non-gpl compatible GStreamer
 * plugins to be used and distributed together with GStreamer and Totem. This
 * permission are above and beyond the permissions granted by the GPL license
 * Totem is covered by.
 *
 * Monday 7th February 2005: Christian Schaller: Add exception clause.
 * See license_change file for details.
 *
 */

#include <gtk/gtk.h>
#include <grilo.h>

void             totem_grilo_setup_icons          (void);
void             totem_grilo_clear_icons          (void);
GdkPixbuf       *totem_grilo_get_icon             (GrlMedia *media,
						   gboolean *thumbnailing);
const GdkPixbuf *totem_grilo_get_video_icon       (void);
const GdkPixbuf *totem_grilo_get_box_icon         (void);
const GdkPixbuf *totem_grilo_get_channel_icon     (void);
const GdkPixbuf *totem_grilo_get_optical_icon     (void);

void             totem_grilo_pause_icon_thumbnailing  (void);
void             totem_grilo_resume_icon_thumbnailing (void);

void             totem_grilo_get_thumbnail        (GObject             *object,
						   GCancellable        *cancellable,
						   GAsyncReadyCallback  callback,
						   gpointer             user_data);
GdkPixbuf       *totem_grilo_get_thumbnail_finish (GObject             *object,
						   GAsyncResult        *res,
						   GError             **error);
